@@ -1,9 +1,12 @@
 package Math::Intersection::StraightLine;
 
+# ABSTRACT: Calculate intersection point for two lines
+
 use 5.006001;
 use strict;
 use warnings;
-our $VERSION = '0.04';
+
+our $VERSION = '0.05';
 
 sub new{
   my ($class) = @_;
@@ -183,12 +186,21 @@ sub _check_point_on_vector{
 }# _check_point_on_vector
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Math::Intersection::StraightLine - Calculate intersection point for two lines
 
+=head1 VERSION
+
+version 0.05
+
 =head1 SYNOPSIS
 
   use Math::Intersection::StraightLine;
@@ -225,21 +237,21 @@ the vector assignment of the line
 
   (10)     +     lambda(30)
   (20)                 (50)
-  
+
 =head2 points
 
 The straight lines are described with two vectors to points on the line
 
   X1 = (10)             X2 = (40)
        (20)                  (70)
-       
+
 =head2 point_limited
 
 If the module should test, if an intersection point of two parts exists
 
   X1 = (10)             X2 = (40)
        (20)                  (70)
-       
+
 The following example should clarify the difference between C<points> and
 C<point_limited>:
 
@@ -250,7 +262,7 @@ C<point_limited>:
   $line_a_part = [[20,60],[30,10]];
   $line_b_part = [[50,80],[50,75]];
   $result = $finder->point_limited($line_a_part,$line_b_part);
-  
+
 The first example returns the intersection point 50/-90, the second returns
 0 because C<$line_a_part> is just a part of C<$line_a> and has no intersection
 point with the part of line b.
@@ -259,7 +271,6 @@ In the first example, the lines are changed to the vectors of the lines.
 
 =head1 EXAMPLES
 
-
   $vector_a = [[20,60],[30,10]];
   $vector_b = [[50,80],[60,30]];
   $result = $finder->point_limited($vector_a,$vector_b);
@@ -284,12 +295,11 @@ In the first example, the lines are changed to the vectors of the lines.
 
 Note! The coordinates for the intersection point can be imprecise!
 
-
   # test y=9x+5 and y=-3x-2
   my $function_one = [9,5];
   my $function_two = [-3,-2];
   $result = $finder->functions($function_one,$function_two);
-  
+
 returns
 
   $VAR1 = [
@@ -305,15 +315,14 @@ returns a new object of C<Math::Intersection::StraightLine>
 
 =head1 AUTHOR
 
-Renee Baecker, E<lt>module@renee-baecker.deE<gt>
+Renee Baecker <reneeb@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005 by Renee Baecker
+This software is Copyright (c) 2015 by Renee Baecker.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.6 or,
-at your option, any later version of Perl 5 you may have available.
+This is free software, licensed under:
 
+  The Artistic License 2.0 (GPL Compatible)
 
 =cut
